==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/armor/EarphoneItem.java <==
package cc.thonly.reverie_dreams.item.armor;

import cc.thonly.reverie_dreams.armor.EarphoneArmorMaterial;
import cc.thonly.reverie_dreams.item.base.ArmorItem;
import cc.thonly.reverie_dreams.server.ParticleTickerManager;
import cc.thonly.reverie_dreams.util.math.Vec3d2Entity;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_8051;

public class EarphoneItem extends ArmorItem {
    public static final List<Vec3d2Entity> VEC_3_DS = new ArrayList<>();

    public EarphoneItem(class_1792.class_1793 settings) {
        super(EarphoneArmorMaterial.INSTANCE, class_8051.field_41934, settings);
    }

    public static synchronized void onUseTick(class_1937 world, class_1309 user, class_1799 stack) {
        if (!world.method_8608() && world instanceof class_3218 sWorld && user instanceof class_3222 player) {
            if (!VEC_3_DS.isEmpty()) {
                for (Vec3d2Entity vec3D2Entity : VEC_3_DS) {
                    if (vec3D2Entity.entity() == user) {
                        continue;
                    }
                    if (player.method_7325()) {
                        continue;
                    }
                    if (vec3D2Entity.entity() instanceof class_1657 playerEntity) {
                        if (playerEntity.method_7325()) {
                            continue;
                        }
                    }
                    double x1 = vec3D2Entity.vec3d().field_1352;
                    double y1 = vec3D2Entity.vec3d().field_1351;
                    double z1 = vec3D2Entity.vec3d().field_1350;
                    double x2 = user.method_23317();
                    double y2 = user.method_23318();
                    double z2 = user.method_23321();
                    double distance = Math.sqrt(Math.pow((x2 - x1), 2) + Math.pow((y2 - y1), 2) + Math.pow((z2 - z1), 2));
                    if (distance < 32) {
                        ParticleTickerManager.joinQueue(sWorld, class_2398.field_38908, 10, vec3D2Entity.vec3d(), user.method_19538(), 1.0f);
                    }
                }
            }
        }
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/armor/EarphoneItem.java <==
package cc.thonly.reverie_dreams.item.armor;

import cc.thonly.reverie_dreams.armor.EarphoneArmorMaterial;
import cc.thonly.reverie_dreams.item.base.ArmorItem;
import cc.thonly.reverie_dreams.server.ArmorAttributeManager;
import cc.thonly.reverie_dreams.server.ParticleTickerManager;
import cc.thonly.reverie_dreams.util.math.Vec3d2Entity;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_8051;

public class EarphoneItem extends ArmorItem {
    public static final List<Vec3d2Entity> VEC_3_DS = new ArrayList<>();

    public EarphoneItem(class_1792.class_1793 settings) {
        super(EarphoneArmorMaterial.INSTANCE, class_8051.field_41934, settings);
        ArmorAttributeManager.register(this::onAccept, this);

    }

    private void onAccept(class_1309 livingEntity, class_1799 itemStack) {
        class_1937 world = livingEntity.method_37908();
        if (!world.method_8608() && world instanceof class_3218 sWorld && livingEntity instanceof class_3222 player) {
            if (!VEC_3_DS.isEmpty()) {
                for (Vec3d2Entity vec3D2Entity : VEC_3_DS) {
                    if (vec3D2Entity.entity() == livingEntity) {
                        continue;
                    }
                    if (player.method_7325()) {
                        continue;
                    }
                    if (vec3D2Entity.entity() instanceof class_1657 playerEntity) {
                        if (playerEntity.method_7325()) {
                            continue;
                        }
                    }
                    double x1 = vec3D2Entity.vec3d().field_1352;
                    double y1 = vec3D2Entity.vec3d().field_1351;
                    double z1 = vec3D2Entity.vec3d().field_1350;
                    double x2 = livingEntity.method_23317();
                    double y2 = livingEntity.method_23318();
                    double z2 = livingEntity.method_23321();
                    double distance = Math.sqrt(Math.pow((x2 - x1), 2) + Math.pow((y2 - y1), 2) + Math.pow((z2 - z1), 2));
                    if (distance < 32) {
                        ParticleTickerManager.joinQueue(sWorld, class_2398.field_38908, 10, vec3D2Entity.vec3d(), livingEntity.method_19538(), 1.0f);
                    }
                }
            }
        }
    }

//    public static synchronized void onUseTick(World world, LivingEntity user, ItemStack stack) {
//
//    }
}
